@@ -199,7 +199,7 @@ Możesz pomóc to rozwiązać.</translation>
     <message>
         <location filename="../qml/pages/LeaderBoard.qml" line="63"/>
         <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
-        <translation type="unfinished"/>
+        <translation>&lt;b&gt;%1 punktów&lt;/b&gt; %2 meldunków</translation>
     </message>
 </context>
 <context>
@@ -447,7 +447,7 @@ Możesz pomóc to rozwiązać.</translation>
     <message>
         <location filename="../qml/pages/Settings.qml" line="81"/>
         <source>Language</source>
-        <translation type="unfinished"/>
+        <translation>Język</translation>
     </message>
     <message>
         <location filename="../qml/pages/Settings.qml" line="109"/>
@@ -482,7 +482,7 @@ Możesz pomóc to rozwiązać.</translation>
     <message>
         <location filename="../qml/pages/Settings.qml" line="209"/>
         <source>INTERVALS</source>
-        <translation>Przerwy</translation>
+        <translation>Okresy</translation>
     </message>
     <message>
         <location filename="../qml/pages/Settings.qml" line="213"/>
@@ -828,12 +828,12 @@ Możesz pomóc to rozwiązać.</translation>
     <message>
         <location filename="../qml/pages/User.qml" line="412"/>
         <source>Checkins</source>
-        <translation>Zameldowania</translation>
+        <translation>Meldunki</translation>
     </message>
     <message>
         <location filename="../qml/pages/User.qml" line="447"/>
         <source>Mayorships</source>
-        <translation>Szefostwa</translation>
+        <translation>Mayorships</translation>
     </message>
     <message>
         <location filename="../qml/pages/User.qml" line="482"/>
@@ -858,7 +858,7 @@ Możesz pomóc to rozwiązać.</translation>
     <message>
         <location filename="../qml/pages/User.qml" line="594"/>
         <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
-        <translation type="unfinished"/>
+        <translation>&lt;b&gt;%1 punktów&lt;/b&gt; %2 meldunków</translation>
     </message>
 </context>
 <context>
