@@ -51,21 +51,42 @@ feed.parseFriendsFeedUpdate = function(response, page) {
         if (prop === "updates") {
             data.updates.items.forEach(
                 function(update){
+                    //DBG-OBJECT
+                    //update = loaddebugobject();
                     if (update.type === "checkin") {
                         for (var i=0;i<page.friendsCheckinsModel.count;i++) {
-                            var info = page.friendsCheckinsModel.get(i).content;
-                            if (info.id !== update.id)
+                            var oldcheckin = page.friendsCheckinsModel.get(i);
+                            if (oldcheckin.content.id !== update.id)
                                 continue;
+                            var checkin = {
+                                "type": oldcheckin.type,
+                                "content": oldcheckin.content
+                            }
                             feed.log("FOUND CHECKIN in MODEL: " + update.id);
-                            info.commentsCount = update.comments.count;
-                            info.comments = update.comments.items;
-                            info.likesCount = update.likes.count;
-                            page.updateItem(i,info);
+                            checkin.content.commentsCount = update.comments.count;
+                            checkin.content.comments = update.comments.items;
+                            checkin.content.likesCount = update.likes.count;
+                            page.updateItem(i,checkin);
+                            break;
+                        }
+                    } else if (update.type === "tip") {
+                        for (var j=0;j<page.friendsCheckinsModel.count;j++) {
+                            var oldtip = page.friendsCheckinsModel.get(j);
+                            if (oldtip.content.id !== update.id)
+                                continue;
+                            var tip = {
+                                "type": oldtip.type,
+                                "content": oldtip.content
+                            }
+                            feed.log("FOUND TIP in MODEL: " + update.id);
+                            tip.content.likesCount = update.likes.count;
+                            page.updateItem(j,tip);
                             break;
                         }
                     } else {
                         feed.log("UPDATE FEED TYPE: " + update.type);
                         feed.debug(function(){ return "UPDATE CONTENT: " + JSON.stringify(update)});
+                        update.debugType = "feed-update";
                         var updateitem = {
                             "type": "feed-update",
                             "content": update
@@ -78,6 +99,7 @@ feed.parseFriendsFeedUpdate = function(response, page) {
                 function(del) {
                     feed.log("UPDATE FEED TYPE: " + del.type);
                     feed.debug(function(){ return "UPDATE CONTENT: " + JSON.stringify(del)});
+                    del.debugType = "feed-delete";
                     var deleteitem = {
                         "type": "feed-delete",
                         "content": del
@@ -89,6 +111,7 @@ feed.parseFriendsFeedUpdate = function(response, page) {
             var propdata = data[prop];
             if (propdata.type === undefined)
                 propdata.type = "feed-" + prop
+            propdata.debugType = propdata.type;
             var propitem = {
                 "type": "feed-" + prop,
                 "content": propdata
@@ -117,8 +140,6 @@ feed.parseFriendsFeed = function(response, page, history) {
         page.trailingMarker = activities.trailingMarker;
 
     var feedObjParser = function(object) {
-        //DBG
-        //object = loaddebugobject();
         var timeObj = object;
         if (timeObj.object !== undefined) {
             timeObj=timeObj.object;
@@ -196,6 +217,11 @@ feed.parseFriendsFeed = function(response, page, history) {
             var install = object.content;
             if (install.type === "plugin") {
                 feed.feedObjParserInstallPlugin(page, object);
+            } else if (install.type === "aggregation") {
+                object.content.object.items.forEach(function(item) {
+                    object.content = item;
+                    feedObjParser(object);
+                });
             } else {
                 feed.log("INSTALL TYPE: " + install.type);
                 feed.debug(function(){return "SAVE VALUE: " + JSON.stringify(object)});
@@ -212,14 +238,29 @@ feed.parseFriendsFeed = function(response, page, history) {
             }
         } else if (object.type === "friend" ) {
             feed.feedObjParserFriend(page, object);
-        } else {
+        } /*else if (object.type === "pageUpdate") {
+            //FIX: Possibly this is not needed, as there is no new formatted
+            // debugContent messages arrived lately
+            //TODO: change to normal logic
+            object.summary = {};
+            object.summary.text = object.shout;
+            object.content = {};
+            object.content.object = object.object;
+            feed.feedObjParserPageUpdate(page, object);
+        }*/ else {
             //un implemented content types goes here
             feed.log("CONTENT TYPE: " + object.type);
+            object.debugType = "unknown-content-type";
             feed.debug(function(){return "CONTENT VALUE: " + JSON.stringify(object)});
             feed.feedObjParserUnknown(page, object);
         }
     }
 
+    //DBG-OBJECT
+    if (api.debugobject) {
+        feedObjParser(loaddebugobject());
+        api.debugobject = false;
+    }
     activities.items.forEach(feedObjParser);
 
     if (!updating) {
@@ -247,9 +288,10 @@ feed.parseFriendsFeed = function(response, page, history) {
 }
 
 feed.feedObjParserUnknown = function(page, object) {
+    object.debugType = object.type;
     var item = {
-                "type": object.type,
-                "content": object
+        "type": object.type,
+        "content": object
     }
     page.addItem(item);
 }
@@ -275,7 +317,7 @@ feed.feedObjParserCheckin = function(page, object) {
             "content": {
                 "id": checkin.id,
                 "shout": parse(checkin.shout),
-                "user": userName,
+                "userName": userName,
                 "userID": checkin.user.id,
                 "mayor": parse(checkin.isMayor),
                 "photo": thumbnailPhoto(checkin.user.photo, 100),
@@ -323,7 +365,7 @@ feed.feedObjParserFriend = function(page, friend) {
         "type": friend.type,
         "content": {
             "id": friend.content.object.id,
-            "user": friend.summary.text,
+            "userName": friend.summary.text,
             "createdAt": makeTime(friend.createdAt),
             "timestamp": friend.createdAt,
         }
@@ -513,7 +555,7 @@ feed.feedObjParserSaveList = function (page, object) {
         "content": {
             "id": list.id,
             "photo": object.thumbnails[0].photo,
-            "user": object.summary.text,
+            "userName": object.summary.text,
             "listName": list.name,
             "shout": list.description,
             "venuePhoto": thumbnailPhoto(list.photo, 300, 300),
@@ -559,7 +601,7 @@ feed.feedObjParserInstallPlugin = function(page, object) {
             "userName": object.summary.text,
             "venueName": plugin.name,
             "photo": plugin.icon,
-            "venuePhoto": plugin.banner,
+            "venuePhoto": parse(plugin.banner),
             "shout": plugin.tagline,
             "url": plugin.detailUrl,
             "createdAt": makeTime(object.createdAt),
